==> qtwebengine-everywhere-opensource-src-5.15.5.zip: qtwebengine-everywhere-src-5.15.5/src/3rdparty/chromium/components/performance_manager/persistence/site_data/site_data_cache_factory_unittest.cc <==
// Copyright 2019 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "components/performance_manager/persistence/site_data/site_data_cache_factory.h"

#include <memory>
#include <utility>

#include "base/macros.h"
#include "base/memory/ptr_util.h"
#include "base/optional.h"
#include "base/run_loop.h"
#include "base/sequenced_task_runner.h"
#include "base/task/post_task.h"
#include "base/test/bind_test_util.h"
#include "base/threading/sequence_bound.h"
#include "components/performance_manager/performance_manager_impl.h"
#include "content/public/test/browser_task_environment.h"
#include "content/public/test/test_browser_context.h"
#include "testing/gtest/include/gtest/gtest.h"

namespace performance_manager {

TEST(SiteDataCacheFactoryTest, EndToEnd) {
  content::BrowserTaskEnvironment task_environment;
  auto performance_manager = PerformanceManagerImpl::Create(base::DoNothing());
  base::SequenceBound<SiteDataCacheFactory> cache_factory(
      PerformanceManager::GetTaskRunner());

  content::TestBrowserContext browser_context;
  cache_factory.Post(FROM_HERE, &SiteDataCacheFactory::OnBrowserContextCreated,
                     browser_context.UniqueId(), browser_context.GetPath(),
                     base::nullopt);

  {
    base::RunLoop run_loop;
    cache_factory.PostTaskWithThisObject(
        FROM_HERE,
        base::BindOnce(
            [](const std::string& browser_context_id,
               base::OnceClosure quit_closure, SiteDataCacheFactory* factory) {
              EXPECT_TRUE(factory);
              EXPECT_NE(nullptr, factory->GetDataCacheForBrowserContext(
                                     browser_context_id));
              EXPECT_NE(nullptr, factory->GetInspectorForBrowserContext(
                                     browser_context_id));
              std::move(quit_closure).Run();
            },
            browser_context.UniqueId(), run_loop.QuitClosure()));
    run_loop.Run();
  }

  cache_factory.Post(FROM_HERE,
                     &SiteDataCacheFactory::OnBrowserContextDestroyed,
                     browser_context.UniqueId());
  {
    base::RunLoop run_loop;
    cache_factory.PostTaskWithThisObject(
        FROM_HERE,
        base::BindOnce(
            [](const std::string& browser_context_id,
               base::OnceClosure quit_closure, SiteDataCacheFactory* factory) {
              EXPECT_EQ(nullptr, factory->GetDataCacheForBrowserContext(
                                     browser_context_id));
              EXPECT_EQ(nullptr, factory->GetInspectorForBrowserContext(
                                     browser_context_id));
              std::move(quit_closure).Run();
            },
            browser_context.UniqueId(), run_loop.QuitClosure()));
    run_loop.Run();
  }

  PerformanceManagerImpl::Destroy(std::move(performance_manager));
  task_environment.RunUntilIdle();
}

}  // namespace performance_manager

==> qtwebengine-everywhere-opensource-src-6.2.13.zip: qtwebengine-everywhere-src-6.2.13/src/3rdparty/chromium/components/performance_manager/persistence/site_data/site_data_cache_factory_unittest.cc <==
// Copyright 2019 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "components/performance_manager/persistence/site_data/site_data_cache_factory.h"

#include <memory>
#include <utility>

#include "base/callback_helpers.h"
#include "base/memory/ptr_util.h"
#include "base/run_loop.h"
#include "base/task/sequenced_task_runner.h"
#include "base/test/bind.h"
#include "base/threading/sequence_bound.h"
#include "components/performance_manager/performance_manager_impl.h"
#include "content/public/test/browser_task_environment.h"
#include "content/public/test/test_browser_context.h"
#include "testing/gtest/include/gtest/gtest.h"
#include "third_party/abseil-cpp/absl/types/optional.h"

namespace performance_manager {

TEST(SiteDataCacheFactoryTest, EndToEnd) {
  content::BrowserTaskEnvironment task_environment;
  auto performance_manager = PerformanceManagerImpl::Create(base::DoNothing());
  base::SequenceBound<SiteDataCacheFactory> cache_factory(
      PerformanceManager::GetTaskRunner());

  content::TestBrowserContext browser_context;
  cache_factory.AsyncCall(&SiteDataCacheFactory::OnBrowserContextCreated)
      .WithArgs(browser_context.UniqueId(), browser_context.GetPath(),
                absl::nullopt);

  {
    base::RunLoop run_loop;
    cache_factory.PostTaskWithThisObject(
        base::BindOnce(
            [](const std::string& browser_context_id,
               base::OnceClosure quit_closure, SiteDataCacheFactory* factory) {
              EXPECT_TRUE(factory);
              EXPECT_NE(nullptr, factory->GetDataCacheForBrowserContext(
                                     browser_context_id));
              EXPECT_NE(nullptr, factory->GetInspectorForBrowserContext(
                                     browser_context_id));
              std::move(quit_closure).Run();
            },
            browser_context.UniqueId(), run_loop.QuitClosure()));
    run_loop.Run();
  }

  cache_factory.AsyncCall(&SiteDataCacheFactory::OnBrowserContextDestroyed)
      .WithArgs(browser_context.UniqueId());
  {
    base::RunLoop run_loop;
    cache_factory.PostTaskWithThisObject(
        base::BindOnce(
            [](const std::string& browser_context_id,
               base::OnceClosure quit_closure, SiteDataCacheFactory* factory) {
              EXPECT_EQ(nullptr, factory->GetDataCacheForBrowserContext(
                                     browser_context_id));
              EXPECT_EQ(nullptr, factory->GetInspectorForBrowserContext(
                                     browser_context_id));
              std::move(quit_closure).Run();
            },
            browser_context.UniqueId(), run_loop.QuitClosure()));
    run_loop.Run();
  }

  PerformanceManagerImpl::Destroy(std::move(performance_manager));
  task_environment.RunUntilIdle();
}

}  // namespace performance_manager
